@@ -1,13 +1,21 @@
 /*  Copyright (c) MIPoPS. All Rights Reserved.
  *
  *  Use of this source code is governed by a BSD-3-Clause license that can
- *  be found in the LICENSE file in the root of the source tree.
+ *  be found in the LICENSE.txt file in the root of the source tree.
  */
 
 //---------------------------------------------------------------------------
 #pragma once
+#include <bitset>
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+enum options_t
+{
+    Option_CaptionPresenceChange,
+    Option_Max,
+};
+
 //---------------------------------------------------------------------------
 enum return_value
 {
@@ -17,5 +25,5 @@ enum return_value
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define Program_Version "0.20.05"
+#define Program_Version "24.07.20260131"
 //---------------------------------------------------------------------------
